@@ -1,10 +1,13 @@
 __all__ = [
 	'BaseRule'
+	, 'BoolRule'
 	, 'ComparisonRule'
+	, 'DateTimeRule'
 	, 'FloatRule'
 	, 'IntegerRule'
 	, 'ListRule'
 	, 'MatchRule'
 	, 'NotMatchRule'
+	, 'NumericRule'
 	, 'StringRule'
 ]
