@@ -1,6 +1,6 @@
 """
 Author: masakokh
-Version: 1.0.0
+Version: 1.1.0
 Note:
 """
 from typing import Any
@@ -14,3 +14,9 @@ class FloatSchema(NumericSchema):
 	keyPrecision		= 'precision'
 	# data type
 	keyDataType			= 'float'
+
+	# translate error
+	NumericSchema.keyErrorDetail.update({
+		keyPrecision: 'No precision'
+		, keyDataType: 'Not a float type'
+	})
